aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/pkg/tar.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/pkg/tar.go')
-rw-r--r--internal/pkg/tar.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/pkg/tar.go b/internal/pkg/tar.go
index 9173a976..f1861edd 100644
--- a/internal/pkg/tar.go
+++ b/internal/pkg/tar.go
@@ -58,8 +58,8 @@ func init() {
})
}
-// Dependencies returns a slice containing the backing file.
-func (a *tarArtifact) Dependencies() []Artifact {
+// Inputs returns a slice containing the backing file.
+func (a *tarArtifact) Inputs() []Artifact {
return []Artifact{a.f}
}